Crate ap_error_macro

Crate ap_error_macro 

Proc macro for generating error types with FlatError trait implementation.

This is a simplified version of bitwarden-error-macro that only supports the flat error type for CLI use.

Attribute Macros

ap_error
A procedural macro for generating error types with FlatError trait implementation.